@@ -108,7 +108,9 @@ function s010_cave.InitFromBlackboard()
   CAVES_TUTO_MAP_ROOM_DONE = Scenario.ReadFromBlackboard(Scenario.LUAPropIDs.CAVES_TUTO_MAP_ROOM_DONE, false)
   QUARENTINE_OPENED = Blackboard.GetProp("GAME_PROGRESS", "QUARENTINE_OPENED")
   s010_cave.CheckScorpiusDead()
-  s010_cave.EmmyCaveSpawnSequence()
+  if not CAVES_EMMY_SPAWNED then
+    s010_cave.EmmyCaveSpawnSequence()
+  end
 
   if Game.GetFromGameBlackboardSection("PlayedCutscenes", "CutScenePlayed[cutscenes/0049centralunitdetectsamus01/0049centralunitdetectsamus01.bmscu]") == 0 then
     local L0_2 =  Game.GetActor( "DoorEmmy11")
@@ -753,7 +755,7 @@ function s010_cave.OnTeleport_Checkpoint_CU()
 end
 
 function s010_cave.Checkpoint_RelocatingEmmy_CU()
-    
+  Game.GetActor("DreadRando_CUDoor").bEnabled = false
   if CurrentScenario.oEmmyEntity ~= nil then
     local oActor = Game.GetActor("LM_EmmyDestroySearchLandmark01")
     if  oActor ~= nil then
@@ -1174,7 +1176,7 @@ function s010_cave.OnSubAreaChange(old_subarea, old_actorgroup, new_subarea, new
       oActor.CUTSCENE:TryLaunchCutscene()
     end
   elseif old_subarea == "collision_camera_049" and new_subarea == "collision_camera_090" then
-    
+    Game.GetActor("DreadRando_CUDoor").bEnabled = false
     local oActor = Game.GetActor("cutsceneplayer_50")
     if oActor ~= nil then
       oActor.CUTSCENE:TryLaunchCutscene()
