@@ -111,6 +111,7 @@ function RandomizerPowerup.Delayed_ChangeSuit(model)
     model_updater.sModelAlias = model
 end
 
+MAX_ENERGY = 1499
 function RandomizerPowerup.IncreaseEnergy(resource)
     if resource == nil then return end
     local item_id = resource.item_id
@@ -122,12 +123,21 @@ function RandomizerPowerup.IncreaseEnergy(resource)
     end
     Game.LogWarn(0, "Increasing player energy.")
 
-    local new = RandomizerPowerup.GetItemAmount("ITEM_MAX_LIFE") + energy
-    RandomizerPowerup.SetItemAmount("ITEM_MAX_LIFE", new)
-    RandomizerPowerup.SetItemAmount("ITEM_CURRENT_LIFE", new)
+    local new_max = RandomizerPowerup.GetItemAmount("ITEM_MAX_LIFE") + energy
+    new_max = math.min(new_max, MAX_ENERGY)
+    
+    local new_current = new_max
+    if item_id == "ITEM_LIFE_SHARDS" and Init.bImmediateEnergyParts then
+        new_current = RandomizerPowerup.GetItemAmount("ITEM_CURRENT_LIFE") + energy
+        new_current = math.min(new_current, MAX_ENERGY)
+    end
+    
+    RandomizerPowerup.SetItemAmount("ITEM_MAX_LIFE", new_max)
+    RandomizerPowerup.SetItemAmount("ITEM_CURRENT_LIFE", new_current)
+
     local life = Game.GetPlayer().LIFE
-    life.fMaxLife = new
-    life.fCurrentLife = new
+    life.fMaxLife = new_max
+    life.fCurrentLife = new_current
 end
 
 function RandomizerPowerup.IncreaseAmmo(resource)
@@ -149,7 +159,11 @@ end
 RandomizerPowerBomb = {}
 setmetatable(RandomizerPowerBomb, {__index = RandomizerPowerup})
 function RandomizerPowerBomb.OnPickedUp(actor, progression)
-    progression = {{item_id = "ITEM_WEAPON_POWER_BOMB_MAX", quantity = 0}}
+    progression = progression or {{item_id = "ITEM_WEAPON_POWER_BOMB_MAX", quantity = 0}}
+    if actor ~= nil then
+        -- actor pickups grant the quantity directly; bosses do not
+        progression[1].quantity = 0
+    end
     local granted = RandomizerPowerup.OnPickedUp(actor, progression)
     if granted ~= nil and granted.item_id == "ITEM_WEAPON_POWER_BOMB_MAX" then
         RandomizerPowerup.SetItemAmount("ITEM_WEAPON_POWER_BOMB", 1)
