@@ -1,11 +1,20 @@
 import dataclasses
+from typing import Optional, Tuple
 
 
+@dataclasses.dataclass(frozen=True)
+class Transform:
+    position: Tuple[float, float, float] = (0.0, 0.0, 0.0)
+    angle: Tuple[float, float, float] = (0.0, 0.0, 0.0)
+    scale: Tuple[float, float, float] = (1.0, 1.0, 1.0)
+
 @dataclasses.dataclass(frozen=True)
 class ModelData:
     bcmdl_path: str
     bmsas: str
     dependencies: tuple[str, ...]
+    grapple_fx: bool = False
+    transform: Optional[Transform] = None
 
 
 ALL_MODEL_DATA: dict[str, ModelData] = {
@@ -24,9 +33,24 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
         ),
     ),
 
+    "powerup_speedbooster": ModelData(
+        bcmdl_path="actors/items/itemsphere/models/speed_booster.bcmdl",
+        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        dependencies=(
+            "actors/items/itemsphere/animations/relax.bcskla",
+            "actors/items/itemsphere/collisions/itemsphere.bmscd",
+            "actors/items/itemsphere/fx/impact.bcptl",
+            "actors/items/itemsphere/fx/impact_itemsphere.bcmdl",
+            "actors/items/itemsphere/fx/impact_itemsphere.bcskla",
+            "actors/items/itemsphere/fx/imats/impact_itemsphere_itemsphere.bsmat",
+            "actors/items/itemsphere/models/speed_booster.bcmdl",
+            "actors/items/itemsphere/models/imats/speedboost_mp_opaque_01.bsmat",
+        ),
+    ),
+
     "powerup_widebeam": ModelData(
         bcmdl_path="actors/items/powerup_widebeam/models/powerup_widebeam.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/powerup_widebeam/charclasses/powerup_widebeam.bmsas",
         dependencies=(
             "actors/items/powerup_widebeam/models/powerup_widebeam.bcmdl",
             "actors/items/powerup_widebeam/models/imats/powerup_widebeam_autoilum.bsmat",
@@ -35,9 +59,20 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
         ),
     ),
 
+    "powerup_wavebeam": ModelData(
+        bcmdl_path="actors/items/powerup_widebeam/models/powerup_wavebeam.bcmdl",
+        bmsas="actors/items/powerup_widebeam/charclasses/powerup_widebeam.bmsas",
+        dependencies=(
+            "actors/items/powerup_widebeam/models/powerup_wavebeam.bcmdl",
+            "actors/items/powerup_widebeam/models/imats/powerup_wavebeam_autoilum.bsmat",
+            "actors/items/powerup_widebeam/models/imats/powerup_wavebeam_bola.bsmat",
+            "actors/items/powerup_widebeam/models/imats/powerup_wavebeam_cangrejo.bsmat",
+        ),
+    ),
+
     "powerup_plasmabeam": ModelData(
         bcmdl_path="actors/items/powerup_plasmabeam/models/powerup_plasmabeam.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/powerup_plasmabeam/charclasses/powerup_plasmabeam.bmsas",
         dependencies=(
             "actors/items/powerup_plasmabeam/models/powerup_plasmabeam.bcmdl",
             "actors/items/powerup_plasmabeam/models/imats/powerup_plasmabeam_autoilum.bsmat",
@@ -48,7 +83,7 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
 
     "powerup_chargebeam": ModelData(
         bcmdl_path="actors/items/powerup_chargebeam/models/powerup_chargebeam.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/powerup_chargebeam/charclasses/powerup_chargebeam.bmsas",
         dependencies=(
             "actors/items/powerup_chargebeam/models/powerup_chargebeam.bcmdl",
             "actors/items/powerup_chargebeam/models/imats/powerup_chargebeam_autoilum.bsmat",
@@ -59,7 +94,7 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
 
     "powerup_diffusionbeam": ModelData(
         bcmdl_path="actors/items/powerup_diffusionbeam/models/powerup_diffusionbeam.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/powerup_diffusionbeam/charclasses/powerup_diffusionbeam.bmsas",
         dependencies=(
             "actors/items/powerup_diffusionbeam/models/powerup_diffusionbeam.bcmdl",
             "actors/items/powerup_diffusionbeam/models/imats/powerup_diffusionbeam_autoilum.bsmat",
@@ -70,17 +105,18 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
 
     "powerup_grapplebeam": ModelData(
         bcmdl_path="actors/items/powerup_grapplebeam/models/powerup_grapplebeam.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/powerup_grapplebeam/charclasses/powerup_grapplebeam.bmsas",
         dependencies=(
             "actors/items/powerup_grapplebeam/fx/auraitemparticle.bcptl",
             "actors/items/powerup_grapplebeam/models/powerup_grapplebeam.bcmdl",
             "actors/items/powerup_grapplebeam/models/imats/powerup_grapplebeam_grapplebeam.bsmat",
         ),
+        grapple_fx=True,
     ),
 
     "powerup_supermissile": ModelData(
         bcmdl_path="actors/items/powerup_supermissile/models/powerup_supermissile.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/powerup_supermissile/charclasses/powerup_supermissile.bmsas",
         dependencies=(
             "actors/items/powerup_supermissile/models/powerup_supermissile.bcmdl",
             "actors/items/powerup_supermissile/models/imats/powerup_supermissile_hologram.bsmat",
@@ -88,25 +124,73 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
         ),
     ),
 
-    "powerup_ghostaura": ModelData(
-        bcmdl_path="actors/items/powerup_ghostaura/models/powerup_ghostaura.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+    "powerup_icemissile": ModelData(
+        bcmdl_path="actors/items/powerup_supermissile/models/powerup_ice__missile.bcmdl",
+        bmsas="actors/items/powerup_supermissile/charclasses/powerup_supermissile.bmsas",
         dependencies=(
-            "actors/items/powerup_ghostaura/models/powerup_ghostaura.bcmdl",
+            "actors/items/powerup_supermissile/models/powerup_ice__missile.bcmdl",
+            "actors/items/powerup_supermissile/models/imats/powerup_supermissile_hologram.bsmat",
+            "actors/items/powerup_supermissile/models/imats/powerup_ice__missile_mp_opaque_01.bsmat",
         ),
     ),
 
-    "powerup_sonar": ModelData(
-        bcmdl_path="actors/items/powerup_sonar/models/powerup_sonar.bcmdl",
+    "powerup_stormmissile": ModelData(
+        bcmdl_path="actors/items/powerup_supermissile/models/powerup_supermissile.bcmdl",
+        bmsas="actors/items/powerup_supermissile/charclasses/powerup_supermissile.bmsas",
+        dependencies=(
+            "actors/items/powerup_supermissile/models/powerup_supermissile.bcmdl",
+            "actors/items/powerup_supermissile/models/imats/powerup_supermissile_hologram.bsmat",
+            "actors/items/powerup_supermissile/models/imats/powerup_supermissile_mp_opaque_01.bsmat",
+            "actors/items/powerup_grapplebeam/fx/auraitemparticle.bcptl",
+        ),
+        grapple_fx=True,
+    ),
+
+    "powerup_opticcamo": ModelData(
+        bcmdl_path="actors/items/item_cube_broken/model/itemcube_camo.bcmdl",
         bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
         dependencies=(
-            "actors/items/powerup_sonar/models/powerup_sonar.bcmdl",
+            "actors/items/item_cube_broken/model/itemcube_camo.bcmdl",
+            "actors/items/item_cube/model/imats/itemcube_camo.bsmat",
+            "actors/items/item_cube/model/imats/itemcube_emisive.bsmat",
         ),
+        transform=Transform(
+            scale=(0.5, 0.5, 0.5),
+            position=(0.0, 30.0, 0.0),
+        )
+    ),
+
+    "powerup_ghostaura": ModelData(
+        bcmdl_path="actors/items/item_cube_broken/model/itemcube_broken.bcmdl",
+        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        dependencies=(
+            "actors/items/item_cube_broken/model/itemcube_broken.bcmdl",
+            "actors/items/item_cube/model/imats/itemcube_cube.bsmat",
+            "actors/items/item_cube/model/imats/itemcube_emisive.bsmat",
+        ),
+        transform=Transform(
+            scale=(0.5, 0.5, 0.5),
+            position=(0.0, 30.0, 0.0),
+        )
+    ),
+
+    "powerup_sonar": ModelData(
+        bcmdl_path="actors/items/item_cube_broken/model/itemcube_sonr.bcmdl",
+        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        dependencies=(
+            "actors/items/item_cube_broken/model/itemcube_sonr.bcmdl",
+            "actors/items/item_cube/model/imats/itemcube_sonr.bsmat",
+            "actors/items/item_cube/model/imats/itemcube_emisive.bsmat",
+        ),
+        transform=Transform(
+            scale=(0.5, 0.5, 0.5),
+            position=(0.0, 30.0, 0.0),
+        )
     ),
 
     "powerup_variasuit": ModelData(
         bcmdl_path="actors/items/powerup_variasuit/models/powerup_variasuit.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/powerup_variasuit/charclasses/powerup_variasuit.bmsas",
         dependencies=(
             "actors/items/powerup_variasuit/models/powerup_variasuit.bcmdl",
             "actors/items/powerup_variasuit/models/imats/powerup_variasuit_material01.bsmat",
@@ -115,7 +199,7 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
 
     "powerup_gravitysuit": ModelData(
         bcmdl_path="actors/items/powerup_gravitysuit/models/powerup_gravitysuit.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/powerup_gravitysuit/charclasses/powerup_gravitysuit.bmsas",
         dependencies=(
             "actors/items/powerup_gravitysuit/models/powerup_gravitysuit.bcmdl",
             "actors/items/powerup_gravitysuit/models/imats/powerup_gravitysuit_ball.bsmat",
@@ -124,9 +208,23 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
         ),
     ),
 
+    "powerup_morphball": ModelData(
+        bcmdl_path="actors/items/powerup_bomb/models/powerup_morph.bcmdl",
+        bmsas="actors/items/powerup_bomb/charclasses/powerup_bomb.bmsas",
+        dependencies=(
+            "actors/items/powerup_bomb/models/powerup_morph.bcmdl",
+            "actors/items/powerup_bomb/models/imats/powerup_morphhologram.bsmat",
+            "actors/items/powerup_bomb/models/imats/powerup_morphmaterial.bsmat",
+        ),
+        transform=Transform(
+            scale=(1.6, 1.6, 1.6),
+            position=(0.0, -20.0, 0.0),
+        )
+    ),
+
     "powerup_bomb": ModelData(
         bcmdl_path="actors/items/powerup_bomb/models/powerup_bomb.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/powerup_bomb/charclasses/powerup_bomb.bmsas",
         dependencies=(
             "actors/items/powerup_bomb/models/powerup_bomb.bcmdl",
             "actors/items/powerup_bomb/models/imats/powerup_bomb_hologram.bsmat",
@@ -134,9 +232,21 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
         ),
     ),
 
+    "powerup_crossbomb": ModelData(
+        bcmdl_path="actors/items/powerup_bomb/models/powerup_bomb.bcmdl",
+        bmsas="actors/items/powerup_bomb/charclasses/powerup_bomb.bmsas",
+        dependencies=(
+            "actors/items/powerup_bomb/models/powerup_bomb.bcmdl",
+            "actors/items/powerup_bomb/models/imats/powerup_bomb_hologram.bsmat",
+            "actors/items/powerup_bomb/models/imats/powerup_bomb_material.bsmat",
+            "actors/items/powerup_grapplebeam/fx/auraitemparticle.bcptl",
+        ),
+        grapple_fx=True,
+    ),
+
     "powerup_doublejump": ModelData(
         bcmdl_path="actors/items/powerup_doublejump/models/powerup_doublejump.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/powerup_doublejump/charclasses/powerup_doublejump.bmsas",
         dependencies=(
             "actors/items/powerup_doublejump/models/powerup_doublejump.bcmdl",
             "actors/items/powerup_doublejump/models/imats/powerup_doublejump_mp_glass_01.bsmat",
@@ -144,9 +254,19 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
         ),
     ),
 
+    "powerup_spidermagnet": ModelData(
+        bcmdl_path="actors/items/powerup_doublejump/models/powerup_magnet.bcmdl",
+        bmsas="actors/items/powerup_doublejump/charclasses/powerup_doublejump.bmsas",
+        dependencies=(
+            "actors/items/powerup_doublejump/models/powerup_magnet.bcmdl",
+            "actors/items/powerup_doublejump/models/imats/powerup_doublejump_mp_magnet01.bsmat",
+            "actors/items/powerup_doublejump/models/imats/powerup_doublejump_mp_white__01.bsmat",
+        ),
+    ),
+
     "powerup_spacejump": ModelData(
         bcmdl_path="actors/items/powerup_spacejump/models/powerup_spacejump.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/powerup_spacejump/charclasses/powerup_spacejump.bmsas",
         dependencies=(
             "actors/items/powerup_spacejump/models/powerup_spacejump.bcmdl",
             "actors/items/powerup_spacejump/models/imats/powerup_spacejump_mat01.bsmat",
@@ -155,7 +275,7 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
 
     "powerup_screwattack": ModelData(
         bcmdl_path="actors/items/powerup_screwattack/models/powerup_screwattack.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/powerup_screwattack/charclasses/powerup_screwattack.bmsas",
         dependencies=(
             "actors/items/powerup_screwattack/models/powerup_screwattack.bcmdl",
             "actors/items/powerup_screwattack/models/imats/powerup_screwattack_mp_opaque_01.bsmat",
@@ -164,7 +284,7 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
 
     "item_energytank": ModelData(
         bcmdl_path="actors/items/item_energytank/models/item_energytank.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/item_energytank/charclasses/item_energytank.bmsas",
         dependencies=(
             "actors/items/item_energytank/models/item_energytank.bcmdl",
             "actors/items/item_energytank/models/imats/item_energytank_mp_opaque_01.bsmat",
@@ -173,7 +293,7 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
 
     "item_energyfragment": ModelData(
         bcmdl_path="actors/items/item_energyfragment/models/item_energyfragment.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/item_energyfragment/charclasses/item_energyfragment.bmsas",
         dependencies=(
             "actors/items/item_energyfragment/models/item_energyfragment.bcmdl",
             "actors/items/item_energyfragment/models/imats/item_energyfragment_glow.bsmat",
@@ -205,12 +325,29 @@ ALL_MODEL_DATA: dict[str, ModelData] = {
 
     "item_powerbombtank": ModelData(
         bcmdl_path="actors/items/item_powerbombtank/models/item_powerbombtank.bcmdl",
-        bmsas="actors/items/itemsphere/charclasses/timeline.bmsas",
+        bmsas="actors/items/item_powerbombtank/charclasses/item_powerbombtank.bmsas",
         dependencies=(
             "actors/items/item_powerbombtank/models/item_powerbombtank.bcmdl",
             "actors/items/item_powerbombtank/models/imats/item_powerbombtank_mat01.bsmat",
             "actors/items/item_powerbombtank/models/imats/item_powerbombtank_mp_fxhologram_01.bsmat",
         ),
+        transform=Transform(
+            scale=(0.8, 0.8, 0.8),
+        )
+    ),
+
+    "powerup_powerbomb": ModelData(
+        bcmdl_path="actors/items/item_powerbombtank/models/item_powerbombtank.bcmdl",
+        bmsas="actors/items/item_powerbombtank/charclasses/item_powerbombtank.bmsas",
+        dependencies=(
+            "actors/items/item_powerbombtank/models/item_powerbombtank.bcmdl",
+            "actors/items/item_powerbombtank/models/imats/item_powerbombtank_mat01.bsmat",
+            "actors/items/item_powerbombtank/models/imats/item_powerbombtank_mp_fxhologram_01.bsmat",
+        ),
+        transform=Transform(
+            scale = (-1.25, 1.25, 1.25),
+            position=(0.0, -30.0, 0.0),
+        ),
     ),
 }
 
